@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: turba/lib/Turba.php,v 1.59.4.46 2009-10-26 17:34:16 jan Exp $
+ * $Horde: turba/lib/Turba.php,v 1.59.4.47 2010/02/13 19:45:07 mrubinsk Exp $
  *
  * @package Turba
  */
@@ -407,7 +407,7 @@ class Turba {
                 // Default share?
                 if (empty($defaults[$params['source']])) {
                     $driver = &Turba_Driver::singleton($params['source']);
-                    if (!is_a($driver, 'PEAR_Error')) {
+                    if (!is_a($driver, 'PEAR_Error') && $driver->hasPermission(PERMS_EDIT)) {
                         $defaults[$params['source']] =
                             $driver->checkDefaultShare(
                                 $shares[$name],
