@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: turba/lib/Views/Browse.php,v 1.12.2.11 2009-10-01 09:57:34 jan Exp $
+ * $Horde: turba/lib/Views/Browse.php,v 1.12.2.12 2010/02/17 15:13:23 mrubinsk Exp $
  *
  * Copyright 2000-2009 The Horde Project (http://www.horde.org/)
  *
@@ -249,6 +249,10 @@ class Turba_View_Browse {
                         break;
                     }
                     $targetDriver = &Turba_Driver::singleton($targetSource);
+                    if (is_a($targetDriver, 'PEAR_Error')) {
+                        $notification->push(sprintf_("Could not load driver for %s", $targetSource), 'horde.error');
+                        break;
+                    }
                     $target = &$targetDriver->getObject($targetKey);
                     if (is_a($target, 'PEAR_Error')) {
                         $notification->push($target, 'horde.error');
@@ -257,6 +261,10 @@ class Turba_View_Browse {
                 } else {
                     $targetSource = $vars->get('targetAddressbook');
                     $targetDriver = &Turba_Driver::singleton($targetSource);
+                    if (is_a($targetDriver, 'PEAR_Error')) {
+                        $notification->push(sprintf_("Could not load driver for %s", $targetSource), 'horde.error');
+                        break;
+                    }
                 }
                 if (!empty($target) && $target->isGroup()) {
                     // Adding contact to an existing list.
